# Automic

This is a library for simple operations on nondeterministic finite automata.
It is primarily being developed as a component of the CCRF sequence-labeling model, and so it may not contain features not directly related to this.